diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/CMakeLists.txt b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/CMakeLists.txt
new file mode 100644
index 0000000000000000000000000000000000000000..92c3d2faab98a27b346c968668db917d9310a030
--- /dev/null
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/CMakeLists.txt
@@ -0,0 +1,33 @@
+################################################################################
+# Package: DerivationFrameworkCore
+################################################################################
+
+# Declare the package name:
+atlas_subdir( DerivationFrameworkCore )
+
+# Declare the package's dependencies:
+atlas_depends_on_subdirs( PUBLIC
+                          Control/AthenaBaseComps
+                          GaudiKernel
+                          PhysicsAnalysis/DerivationFramework/DerivationFrameworkInterfaces
+                          PRIVATE
+                          Control/AthenaKernel
+                          Control/DataModel
+                          Control/SGTools
+                          Control/StoreGate )
+
+# Component(s) in the package:
+atlas_add_library( DerivationFrameworkCoreLib
+                   src/*.cxx
+                   PUBLIC_HEADERS DerivationFrameworkCore
+                   LINK_LIBRARIES AthenaBaseComps GaudiKernel StoreGateLib SGtests
+                   PRIVATE_LINK_LIBRARIES AthenaKernel DataModel SGTools )
+
+atlas_add_component( DerivationFrameworkCore
+                     src/components/*.cxx
+                     LINK_LIBRARIES AthenaBaseComps GaudiKernel AthenaKernel DataModel SGTools StoreGateLib SGtests DerivationFrameworkCoreLib )
+
+# Install files from the package:
+atlas_install_python_modules( python/*.py )
+atlas_install_joboptions( share/*.py )
+
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4EMPFlowJetsCPContent.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4EMPFlowJetsCPContent.py
index 186529793365d0215125a9ee2768ec79d55290ee..9d18f95b4f5966eccde2dadb4db3cb59a92265b0 100644
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4EMPFlowJetsCPContent.py
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4EMPFlowJetsCPContent.py
@@ -4,7 +4,7 @@ AntiKt4EMPFlowJetsCPContent = [
 "AntiKt4EMPFlowJets",
 "AntiKt4EMPFlowJetsAux.pt.eta.phi.m.JetConstitScaleMomentum_pt.JetConstitScaleMomentum_eta.JetConstitScaleMomentum_phi.JetConstitScaleMomentum_m.ActiveArea4vec_eta.ActiveArea4vec_m.ActiveArea4vec_phi.ActiveArea4vec_pt.GhostMuonSegment.GhostMuonSegmentCount.EnergyPerSampling.SumPtChargedPFOPt500.NumTrkPt500.TrackWidthPt500.NumTrkPt1000.TrackWidthPt1000.constituentLinks.btaggingLink.GhostTruthAssociationLink",
 "MuonSegments",
-"MuonSegmentsAux.-",
+"MuonSegmentsAux.",
 "PrimaryVertices",
 "PrimaryVerticesAux.trackParticleLinks.neutralParticleLinks" 
 ]
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4EMTopoJetsCPContent.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4EMTopoJetsCPContent.py
index b17f41cbfa532517b47222ebe99a4cab8cab9b3e..934c782ca4403ae1ebbf2eede157d1a95751373c 100644
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4EMTopoJetsCPContent.py
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4EMTopoJetsCPContent.py
@@ -4,7 +4,7 @@ AntiKt4EMTopoJetsCPContent = [
 "AntiKt4EMTopoJets",
 "AntiKt4EMTopoJetsAux.pt.eta.phi.m.JetConstitScaleMomentum_pt.JetConstitScaleMomentum_eta.JetConstitScaleMomentum_phi.JetConstitScaleMomentum_m.HECFrac.HECQuality.JVF.LArQuality.NegativeE.NumTrkPt1000.NumTrkPt500.SumPtTrkPt500.Timing.TrackWidthPt1000.Width.ActiveArea4vec_eta.ActiveArea4vec_m.ActiveArea4vec_phi.ActiveArea4vec_pt.AverageLArQF.EMFrac.EnergyPerSampling.FracSamplingMax.GhostMuonSegment.GhostMuonSegmentCount.OriginCorrected.PileupCorrected.DetectorEta.JetOriginConstitScaleMomentum_pt.JetPileupScaleMomentum_pt.JetPileupScaleMomentum_eta.JetPileupScaleMomentum_phi.JetPileupScaleMomentum_m.JetEtaJESScaleMomentum_pt.JetEtaJESScaleMomentum_eta.JetEtaJESScaleMomentum_phi.JetEtaJESScaleMomentum_m.JetGSCScaleMomentum_pt.JetGSCScaleMomentum_eta.JetGSCScaleMomentum_phi.JetGSCScaleMomentum_m.JetInsituScaleMomentum_pt.JetInsituScaleMomentum_eta.JetInsituScaleMomentum_phi.JetInsituScaleMomentum_m.constituentLinks.btaggingLink.GhostBHadronsFinal.GhostBHadronsInitial.GhostBQuarksFinal.GhostCHadronsFinal.GhostCHadronsInitial.GhostCQuarksFinal.GhostHBosons.GhostPartons.GhostTQuarksFinal.GhostTausFinal.GhostWBosons.GhostZBosons.GhostTruth.OriginVertex.GhostAntiKt3TrackJet.GhostAntiKt4TrackJet.GhostTrack.GhostTruthAssociationLink.HighestJVFVtx.JetOriginConstitScaleMomentum_eta.JetOriginConstitScaleMomentum_m.JetOriginConstitScaleMomentum_phi.JvtJvfcorr.JvtRpt.Jvt.FracSamplingMaxIndex.LeadingClusterPt.ECPSFraction.N90Constituents.LeadingClusterSecondLambda.LeadingClusterCenterLambda.LeadingClusterSecondR.CentroidR.OotFracClusters5.OotFracClusters10.ConeTruthLabelID.PartonTruthLabelID",
 "MuonSegments",
-"MuonSegmentsAux.-",
+"MuonSegmentsAux.",
 "PrimaryVertices",
 "PrimaryVerticesAux.trackParticleLinks.neutralParticleLinks"
 ]
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4LCTopoJetsCPContent.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4LCTopoJetsCPContent.py
index af182e402cef502677dbdd8d8eb09efdad902a37..2ff1ae2f21d83220b7ef52e57bd3626066aed222 100644
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4LCTopoJetsCPContent.py
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/AntiKt4LCTopoJetsCPContent.py
@@ -4,7 +4,7 @@ AntiKt4LCTopoJetsCPContent = [
 "AntiKt4LCTopoJets",
 "AntiKt4LCTopoJetsAux.pt.eta.phi.m.JetConstitScaleMomentum_pt.JetConstitScaleMomentum_eta.JetConstitScaleMomentum_phi.JetConstitScaleMomentum_m.HECFrac.HECQuality.JVF.LArQuality.NegativeE.NumTrkPt1000.NumTrkPt500.SumPtTrkPt500.Timing.TrackWidthPt1000.Width.ActiveArea4vec_eta.ActiveArea4vec_m.ActiveArea4vec_phi.ActiveArea4vec_pt.AverageLArQF.EMFrac.EnergyPerSampling.FracSamplingMax.GhostMuonSegment.GhostMuonSegmentCount.OriginCorrected.PileupCorrected.DetectorEta.JetPileupScaleMomentum_pt.JetPileupScaleMomentum_eta.JetPileupScaleMomentum_phi.JetPileupScaleMomentum_m.JetOriginConstitScaleMomentum_pt.JetEtaJESScaleMomentum_pt.JetEtaJESScaleMomentum_eta.JetEtaJESScaleMomentum_phi.JetEtaJESScaleMomentum_m.JetGSCScaleMomentum_pt.JetGSCScaleMomentum_eta.JetGSCScaleMomentum_phi.JetGSCScaleMomentum_m.JetInsituScaleMomentum_pt.JetInsituScaleMomentum_eta.JetInsituScaleMomentum_phi.JetInsituScaleMomentum_m.constituentLinks.btaggingLink.GhostBHadronsFinal.GhostBHadronsInitial.GhostBQuarksFinal.GhostCHadronsFinal.GhostCHadronsInitial.GhostCQuarksFinal.GhostHBosons.GhostPartons.GhostTQuarksFinal.GhostTausFinal.GhostWBosons.GhostZBosons.GhostTruth.OriginVertex.GhostAntiKt3TrackJet.GhostAntiKt4TrackJet.GhostTrack.GhostTruthAssociationLink.HighestJVFVtx.JetOriginConstitScaleMomentum_eta.JetOriginConstitScaleMomentum_m.JetOriginConstitScaleMomentum_phi.JvtJvfcorr.JvtRpt.Jvt.FracSamplingMaxIndex.LeadingClusterPt.ECPSFraction.N90Constituents.LeadingClusterSecondLambda.LeadingClusterCenterLambda.LeadingClusterSecondR.CentroidR.OotFracClusters5.OotFracClusters10.ConeTruthLabelID.PartonTruthLabelID",
 "MuonSegments",
-"MuonSegmentsAux.-",
+"MuonSegmentsAux.",
 "PrimaryVertices",
 "PrimaryVerticesAux.trackParticleLinks.neutralParticleLinks"
 ]
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/BPhysTriggerContent.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/BPhysTriggerContent.py
index e3e22aaad533df106dd9002a26063eb48a449a85..30dc28f89df087cf69649820ab06e5af3b3290ae 100644
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/BPhysTriggerContent.py
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/BPhysTriggerContent.py
@@ -12,9 +12,9 @@ BPhysTriggerContent = [
 "HLT_xAOD__TrigBphysContainer_L2BMuMuFex",
 "HLT_xAOD__TrigBphysContainer_L2BMuMuFexAux.",
 "HLT_xAOD__TrackParticleContainer_InDetTrigTrackingxAODCnv_Muon_EFID",
-"HLT_xAOD__TrackParticleContainer_InDetTrigTrackingxAODCnv_Muon_EFIDAux.pt.eta.phi.d0.z0",
+"HLT_xAOD__TrackParticleContainer_InDetTrigTrackingxAODCnv_Muon_EFIDAux.phi.d0.z0.theta.qOverP",
 "HLT_xAOD__TrackParticleContainer_InDetTrigTrackingxAODCnv_Muon_IDTrig",
-"HLT_xAOD__TrackParticleContainer_InDetTrigTrackingxAODCnv_Muon_IDTrigAux.pt.eta.phi.d0.z0"
+"HLT_xAOD__TrackParticleContainer_InDetTrigTrackingxAODCnv_Muon_IDTrigAux.phi.d0.z0.theta.qOverP"
 #"HLT_xAOD__TrackParticleContainer_InDetTrigTrackingxAODCnv_Bphysics_IDTrig",
 #"HLT_xAOD__TrackParticleContainer_InDetTrigTrackingxAODCnv_Bphysics_IDTrigAux.pt.eta.phi.d0.z0"
 ]
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/ElectronsCPContent.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/ElectronsCPContent.py
index 13e242e78a40de299bd9cb267db35b4bc0a6da43..553b7f01663b7547971a05b659774779cacee2a1 100644
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/ElectronsCPContent.py
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/ElectronsCPContent.py
@@ -2,9 +2,11 @@
 
 ElectronsCPContent = [
 "Electrons",
-"ElectronsAux.trackParticleLinks.pt.eta.phi.m.truthParticleLink.truthOrigin.truthType.caloClusterLinks.author.OQ.ethad1.ethad.f1.f3.f3core.e233.e237.e277.weta1.weta2.e2tsts1.fracs1.wtots1.emins1.emaxs1.etcone20.ptcone30.deltaEta1.deltaPhi2.deltaPhiRescaled2.Loose.Medium.Tight.DFCommonElectronsLHLoose.DFCommonElectronsLHMedium.DFCommonElectronsLHTight.DFCommonElectronsML.ptcone20.ptcone30.ptcone40.ptvarcone20.ptvarcone30.ptvarcone40.topoetcone20.topoetcone30.topoetcone40.charge.Reta.Rphi.Eratio.Rhad.Rhad1.DeltaE.DFCommonElectronsIsEMLoose.DFCommonElectronsIsEMMedium.DFCommonElectronsIsEMTight.topoetcone20ptCorrection.topoetcone30ptCorrection.topoetcone40ptCorrection.etcone20ptCorrection.etcone30ptCorrection.etcone40ptCorrection",
+"ElectronsAux.trackParticleLinks.pt.eta.phi.m.truthParticleLink.truthOrigin.truthType.caloClusterLinks.author.OQ.ethad1.ethad.f1.f3.f3core.e233.e237.e277.weta1.weta2.e2tsts1.fracs1.wtots1.emins1.emaxs1.etcone20.ptcone30.deltaEta1.deltaPhi2.deltaPhiRescaled2.Loose.Medium.Tight.DFCommonElectronsLHLoose.DFCommonElectronsLHMedium.DFCommonElectronsLHTight.DFCommonElectronsML.ptcone20.ptcone30.ptcone40.ptvarcone20.ptvarcone30.ptvarcone40.topoetcone20.topoetcone30.topoetcone40.charge.Reta.Rphi.Eratio.Rhad.Rhad1.DeltaE.DFCommonElectronsIsEMLoose.DFCommonElectronsIsEMMedium.DFCommonElectronsIsEMTight.topoetcone20ptCorrection.topoetcone30ptCorrection.topoetcone40ptCorrection.etcone20ptCorrection.etcone30ptCorrection.etcone40ptCorrection.LHLoose",
 "GSFTrackParticles",
-"GSFTrackParticlesAux.phi.d0.theta.qOverP.definingParametersCovMatrix.parameterX.parameterPX.parameterPY.parameterPZ.parameterPosition.numberOfBLayerHits.numberOfBLayerOutliers.expectBLayerHit.numberOfPixelHits.numberOfPixelOutliers.numberOfPixelDeadSensors.numberOfSCTHits.numberOfSCTOutliers.numberOfSCTDeadSensors.numberOfTRTHits.numberOfTRTOutliers.numberOfTRTHighThresholdHits.numberOfTRTHighThresholdOutliers.numberOfTRTXenonHits.z0.vz.vertexLink.numberOfInnermostPixelLayerHits.numberOfInnermostPixelLayerOutliers.numberOfNextToInnermostPixelLayerOutliers.expectInnermostPixelLayerHit.eProbabilityComb.truthParticleLink.originalTrackParticle.eProbabilityHT",
+"GSFTrackParticlesAux.phi.d0.theta.qOverP.definingParametersCovMatrix.parameterX.parameterPX.parameterPY.parameterPZ.parameterPosition.numberOfBLayerHits.numberOfBLayerOutliers.expectBLayerHit.numberOfPixelHits.numberOfPixelOutliers.numberOfPixelDeadSensors.numberOfSCTHits.numberOfSCTOutliers.numberOfSCTDeadSensors.numberOfTRTHits.numberOfTRTOutliers.numberOfTRTHighThresholdHits.numberOfTRTHighThresholdOutliers.numberOfTRTXenonHits.z0.vz.vertexLink.numberOfInnermostPixelLayerHits.numberOfInnermostPixelLayerOutliers.numberOfNextToInnermostPixelLayerOutliers.expectInnermostPixelLayerHit.eProbabilityComb.truthParticleLink.originalTrackParticle.eProbabilityHT.numberOfNextToInnermostPixelLayerHits.expectNextToInnermostPixelLayerHit",
+"GSFConversionVertices",
+"GSFConversionVerticesAux.px.py.pz",
 "PrimaryVertices",
 "PrimaryVerticesAux.trackParticleLinks.vertexType.neutralParticleLinks",
 "egammaClusters",
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/MuonsCPContent.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/MuonsCPContent.py
deleted file mode 100644
index a8eccd50b85d9a6c8b0cba0e3ec8b1548437d8c7..0000000000000000000000000000000000000000
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/MuonsCPContent.py
+++ /dev/null
@@ -1,27 +0,0 @@
-# Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
-
-MuonsCPContent = [
-"CombinedMuonTrackParticles",
-"CombinedMuonTrackParticlesAux.phi.theta.qOverP.numberOfPixelHits.numberOfPixelHoles.numberOfPixelDeadSensors.numberOfSCTHits.numberOfSCTHoles.numberOfSCTDeadSensors.numberOfTRTHits.numberOfTRTOutliers.numberOfPrecisionLayers.numberOfPrecisionHoleLayers.d0.z0.vz.definingParametersCovMatrix.vertexLink.truthParticleLink.chiSquared.numberDoF.numberOfPhiLayers.numberOfPhiHoleLayers",
-"ExtrapolatedMuonTrackParticles",
-"GSFTrackParticles",
-"InDetTrackParticles",
-"Muons",
-"Photons",
-"egammaClusters",
-"Electrons",
-"ElectronsAux.trackParticleLinks.pt.eta.phi.m.f1.topoetcone40.truthParticleLink.caloClusterLinks",
-"ExtrapolatedMuonTrackParticlesAux.phi.theta.qOverP.numberOfPixelHits.numberOfPixelDeadSensors.numberOfPrecisionLayers.d0.z0.vz.definingParametersCovMatrix.vertexLink.truthParticleLink.chiSquared.numberDoF.numberOfPhiLayers.numberOfPhiHoleLayers",
-"GSFTrackParticlesAux.phi.theta.d0.z0.vz.definingParametersCovMatrix.vertexLink.truthParticleLink.originalTrackParticle.qOverP",
-"InDetTrackParticlesAux.phi.theta.qOverP.numberOfPixelHits.numberOfPixelHoles.numberOfPixelDeadSensors.numberOfSCTHits.numberOfSCTHoles.numberOfSCTDeadSensors.numberOfTRTHits.numberOfTRTOutliers.numberOfPrecisionLayers.d0.z0.vz.definingParametersCovMatrix.vertexLink.truthParticleLink.chiSquared.numberDoF.numberOfPhiLayers.numberOfPhiHoleLayers.numberOfPrecisionHoleLayers",
-"MuonSpectrometerTrackParticles",
-"MuonSpectrometerTrackParticlesAux.phi.d0.z0.vz.definingParametersCovMatrix.vertexLink.theta.qOverP.truthParticleLink",
-"MuonsAux.pt.eta.phi.truthType.truthOrigin.author.muonType.quality.inDetTrackParticleLink.muonSpectrometerTrackParticleLink.combinedTrackParticleLink.InnerDetectorPt.MuonSpectrometerPt.DFCommonGoodMuon.momentumBalanceSignificance.clusterLink.ptcone20.ptcone30.ptcone40.ptvarcone20.ptvarcone30.ptvarcone40.topoetcone20.topoetcone30.topoetcone40.innerSmallHits.truthParticleLink.charge.CaloLRLikelihood.CaloMuonIDTag.extrapolatedMuonSpectrometerTrackParticleLink.numberOfPrecisionLayers.numberOfPrecisionHoleLayers.innerLargeHits.muonSegmentLinks.numberOfGoodPrecisionLayers.innerSmallHoles.innerLargeHoles.middleSmallHoles.middleLargeHoles.outerSmallHoles.outerLargeHoles.extendedSmallHoles.extendedLargeHoles.innerClosePrecisionHits.middleClosePrecisionHits.outerClosePrecisionHits.extendedClosePrecisionHits.innerOutBoundsPrecisionHits.middleOutBoundsPrecisionHits.outerOutBoundsPrecisionHits.extendedOutBoundsPrecisionHits.combinedTrackOutBoundsPrecisionHits.isEndcapGoodLayers.isSmallGoodSectors.middleLargeHits.middleSmallHits.outerLargeHits.outerSmallHits",
-"PhotonsAux.pt.eta.phi.m.caloClusterLinks.author.f1.topoetcone40.Tight.truthParticleLink.vertexLinks",
-"egammaClustersAux.calEta.calPhi.calE.calM",
-"egammaTopoSeededClusters",
-"egammaTopoSeededClustersAux.calEta.calPhi",
-"InDetForwardTrackParticles",
-"InDetForwardTrackParticlesAux.theta.phi.qOverP.numberOfPrecisionLayers.numberOfPrecisionHoleLayers.numberOfPixelHits.numberOfPixelDeadSensors.numberOfSCTHits.numberOfSCTDeadSensors.d0.z0.vz.definingParametersCovMatrix",
-"ExtrapolatedMuonTrackParticlesAux.numberOfPrecisionHoleLayers.numberOfPixelHoles.numberOfSCTHits.numberOfSCTHoles.numberOfSCTDeadSensors.numberOfTRTHits.numberOfTRTOutliers"
-]
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/SlimmingHelper.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/SlimmingHelper.py
index 04e0a0621a69bbc92bdb0cf25f5a79de5f7aca7e..efdad13a16a5a3882e10871bec67ab8e68a50e8e 100644
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/SlimmingHelper.py
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/SlimmingHelper.py
@@ -280,13 +280,15 @@ class SlimmingHelper:
 			from DerivationFrameworkCore.PhotonsCPContent import PhotonsCPContent
 			items.extend(PhotonsCPContent)
 		elif collectionName=="Muons":
-			#from DerivationFrameworkMuons.MuonsCPContent import MuonsCPContent
-			from DerivationFrameworkCore.MuonsCPContent import MuonsCPContent
+			from DerivationFrameworkMuons.MuonsCPContent import MuonsCPContent
+#			from DerivationFrameworkCore.MuonsCPContent import MuonsCPContent
 			items.extend(MuonsCPContent)
 		elif collectionName=="TauJets":
-			#from DerivationFrameworkTau.TauJetsCPContent import TauJetsCPContent
-			from DerivationFrameworkCore.TauJetsCPContent import TauJetsCPContent
+			from DerivationFrameworkTau.TauJetsCPContent import TauJetsCPContent
 			items.extend(TauJetsCPContent)
+		elif collectionName=="TauMVATESJets":
+			from DerivationFrameworkTau.TauMVATESContent import TauMVATESContent
+			items.extend(TauMVATESContent)
 		elif collectionName=="MET_Reference_AntiKt4LCTopo":
 			#from DerivationFrameworkJetEtMiss.MET_Reference_AntiKt4LCTopoCPContent import MET_Reference_AntiKt4LCTopoCPContent
 			from DerivationFrameworkCore.MET_Reference_AntiKt4LCTopoCPContent import MET_Reference_AntiKt4LCTopoCPContent
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/TauJetsCPContent.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/TauJetsCPContent.py
deleted file mode 100644
index 14290fb80ba3092af0e57f7e8b6c692561ba66ee..0000000000000000000000000000000000000000
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/TauJetsCPContent.py
+++ /dev/null
@@ -1,9 +0,0 @@
-# Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
-
-TauJetsCPContent = [
-"AntiKt4LCTopoJets",
-"InDetTrackParticles",
-"InDetTrackParticlesAux.phi.vertexLink.theta.qOverP.truthParticleLink.truthMatchProbability",
-"TauJets",
-"TauJetsAux.pt.eta.phi.m.trackLinks.wideTrackLinks.otherTrackLinks.jetLink.vertexLink.secondaryVertexLink.hadronicPFOLinks.shotPFOLinks.chargedPFOLinks.neutralPFOLinks.pi0PFOLinks.protoChargedPFOLinks.protoNeutralPFOLinks.protoPi0PFOLinks.charge.isTauFlags.BDTJetScore.BDTEleScore.conversionTrackLinks.charged_PFOLinks.neutral_PFOLinks.pi0_PFOLinks.cellBased_Charged_PFOLinks.cellBased_Neutral_PFOLinks.cellBased_Pi0_PFOLinks.eflowRec_Charged_PFOLinks.eflowRec_Neutral_PFOLinks.eflowRec_Pi0_PFOLinks.shot_PFOLinks"
-]
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/WeightMetadata.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/WeightMetadata.py
index f40dc22568f5deaca1b933ced73d2e749ef1b924..ccfe3fa0cb64d2d1c5b60e87ca5cf94c82486bc6 100644
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/WeightMetadata.py
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/WeightMetadata.py
@@ -100,30 +100,30 @@ def addWeightsHist(stream, seq, svcMgr, CfgMgr, ToolSvc, derivName, fileName, pd
 from DerivationFrameworkCore.DerivationFrameworkMaster import *
 #addWeights(DerivationFrameworkJob, {'CT10nlo':52, 'MSTW2008nlo68cl': 40, 'NNPDF23_lo_as_0130_qed': 100, 'NNPDF30_nlo_as_0118': 100}, "")
 listPDF = {}
-listPDF["CT14nlo"] = 56
-listPDF["CT14nlo_NF4"] = 0
-listPDF["NNPDF30_nlo_as_0118"] = 100
-listPDF["NNPDF30_nlo_as_0118_nf_4"] = 100
+#listPDF["CT14nlo"] = 56
+#listPDF["CT14nlo_NF4"] = 0
+#listPDF["NNPDF30_nlo_as_0118"] = 100
+#listPDF["NNPDF30_nlo_as_0118_nf_4"] = 100
 listPDF["MMHT2014nlo68cl"] = 50
-listPDF["MMHT2014nlo68cl_nf4"] = 50
-listPDF["PDF4LHC15_nlo_100"] = 100
+#listPDF["MMHT2014nlo68cl_nf4"] = 50
+#listPDF["PDF4LHC15_nlo_100"] = 100
 listPDF["PDF4LHC15_nlo_30"] = 30
-listPDF["PDF4LHC15_nlo_mc"] = 100
-listPDF["PDF4LHC15_nlo_asvar"] = 1
-listPDF["NNPDF23_lo_as_0119_qed"] = 100
-listPDF["NNPDF23_nlo_as_0118_qed"] = 100
-listPDF["NNPDF30_nnlo_as_0118"] = 100
-listPDF["NNPDF30_lo_as_0130"] = 100
+#listPDF["PDF4LHC15_nlo_mc"] = 100
+#listPDF["PDF4LHC15_nlo_asvar"] = 1
+#listPDF["NNPDF23_lo_as_0119_qed"] = 100
+#listPDF["NNPDF23_nlo_as_0118_qed"] = 100
+#listPDF["NNPDF30_nnlo_as_0118"] = 100
+listPDF["NNPDF30_nlo_as_0118"] = 100
 listPDF["CT10"] = 52
-listPDF["cteq66"] = 44
-listPDF["MSTW2008nlo68cl"] = 40
-listPDF["cteq6l1"] = 0
-listPDF["abm12lhc_5_nnlo"] = 28
-listPDF["HERAPDF20_NLO_EIG"] = 28
-listPDF["HERAPDF20_NLO_VAR"] = 13
-listPDF["ATLAS-epWZ12-EIG"] = 30
-listPDF["ATLAS-epWZ12-VAR"] = 11
-listPDF["abm12lhc_4_nnlo"] = 28
+#listPDF["cteq66"] = 44
+#listPDF["MSTW2008nlo68cl"] = 40
+#listPDF["cteq6l1"] = 0
+#listPDF["abm12lhc_5_nnlo"] = 28
+#listPDF["HERAPDF20_NLO_EIG"] = 28
+#listPDF["HERAPDF20_NLO_VAR"] = 13
+#listPDF["ATLAS-epWZ12-EIG"] = 30
+#listPDF["ATLAS-epWZ12-VAR"] = 11
+#listPDF["abm12lhc_4_nnlo"] = 28
 
 # skip this in data
 from AthenaCommon.GlobalFlags import globalflags
diff --git a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/DerivationFrameworkProdFlags.py b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/DerivationFrameworkProdFlags.py
index 84017f8bfd672912b2e64648a559e5e0b18a366f..29f9d610fe90feaff7443ee47565f3877eb42bd4 100644
--- a/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/DerivationFrameworkProdFlags.py
+++ b/PhysicsAnalysis/DerivationFramework/DerivationFrameworkCore/python/DerivationFrameworkProdFlags.py
@@ -15,8 +15,21 @@ listAllKnownDPD=[]
 # Defined by ASG for tests/examples
 ####################################
 
+class WriteDAOD_PASSTHRStream(JobProperty):
+    """ Produce the DPD for DAOD_PASSTHR - pass through """
+    statusOn     = True
+    allowedTypes = ['bool']
+    StoredValue  = False
+    StreamName   = "StreamDAOD_PASSTHR"
+    FileName     = ""
+    isVirtual      = False
+    DPDMakerScript = "DerivationFrameworkExamples/PassThroughExample.py"
+    pass
+jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_PASSTHRStream)
+listAODtoDPD.append(WriteDAOD_PASSTHRStream.StreamName)
+
 class WriteDAOD_TEST1Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST1 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -29,7 +42,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST1Stream
 listAODtoDPD.append(WriteDAOD_TEST1Stream.StreamName)
 
 class WriteDAOD_TEST2Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST2 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -42,7 +55,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST2Stream
 listAODtoDPD.append(WriteDAOD_TEST2Stream.StreamName)
 
 class WriteDAOD_TEST3Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST3 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -55,7 +68,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST3Stream
 listAODtoDPD.append(WriteDAOD_TEST3Stream.StreamName)
 
 class WriteDAOD_TEST4Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST4 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -68,7 +81,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST4Stream
 listAODtoDPD.append(WriteDAOD_TEST4Stream.StreamName)
 
 class WriteDAOD_TEST5Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST5 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -81,7 +94,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST5Stream
 listAODtoDPD.append(WriteDAOD_TEST5Stream.StreamName)
 
 class WriteDAOD_TEST6Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST6 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -94,7 +107,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST6Stream
 listAODtoDPD.append(WriteDAOD_TEST6Stream.StreamName)
 
 class WriteDAOD_TEST7Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST7 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -107,7 +120,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST7Stream
 listAODtoDPD.append(WriteDAOD_TEST7Stream.StreamName)
 
 class WriteDAOD_TEST8Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST8 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -120,7 +133,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST8Stream
 listAODtoDPD.append(WriteDAOD_TEST8Stream.StreamName)
 
 class WriteDAOD_TEST9Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST9 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -133,7 +146,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST9Stream
 listAODtoDPD.append(WriteDAOD_TEST9Stream.StreamName)
 
 class WriteDAOD_TEST10Stream(JobProperty):
     """ Produce the DPD for DAOD_TEST10 - derivation framework test """
     statusOn     = True
     allowedTypes = ['bool']
     StoredValue  = False
@@ -876,6 +889,32 @@ class WriteDAOD_SUSY12Stream(JobProperty):
 jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_SUSY12Stream)
 listAODtoDPD.append(WriteDAOD_SUSY12Stream.StreamName)
 
+class WriteDAOD_SUSY13Stream(JobProperty):
+    """SUSY13 derivation"""
+    statusOn = True
+    allowedTypes = ['bool']
+    StoredValue = False
+    StreamName = 'StreamDAOD_SUSY13'
+    FileName = ''
+    isVirtual = False
+    DPDMakerScript = "DerivationFrameworkSUSY/SUSY13.py"
+    pass
+jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_SUSY13Stream)
+listAODtoDPD.append(WriteDAOD_SUSY13Stream.StreamName)
+
+class WriteDAOD_SUSY14Stream(JobProperty):
+    """SUSY14 derivation"""
+    statusOn = True
+    allowedTypes = ['bool']
+    StoredValue = False
+    StreamName = 'StreamDAOD_SUSY14'
+    FileName = ''
+    isVirtual = False
+    DPDMakerScript = "DerivationFrameworkSUSY/SUSY14.py"
+    pass
+jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_SUSY14Stream)
+listAODtoDPD.append(WriteDAOD_SUSY14Stream.StreamName)
+
 
 #################################
 # Defined by the Exotics group
@@ -1473,6 +1512,19 @@ class WriteDAOD_FTAG4Stream (JobProperty):
 jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_FTAG4Stream)
 listAODtoDPD.append(WriteDAOD_FTAG4Stream.StreamName)
 
+class WriteDAOD_FTAG5Stream (JobProperty):
+     """FTAG5 derivation"""
+     statusOn = True
+     allowedTypes = ['bool']
+     StoredValue = False
+     StreamName = 'StreamDAOD_FTAG5'
+     FileName = ''
+     isVirtual = False
+     DPDMakerScript = "DerivationFrameworkFlavourTag/FTAG5.py"
+     pass
+jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_FTAG5Stream)
+listAODtoDPD.append(WriteDAOD_FTAG5Stream.StreamName)
+
 ######################################
 # Defined by the B-physics group
 ######################################
@@ -15,8 +15,21 @@ listAllKnownDPD=[]
 class WriteDAOD_TEST1Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST1 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST1 - skimming example """
     statusOn     = True
     allowedTypes = ['bool']
@@ -29,7 +42,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST1Stream
 
 class WriteDAOD_TEST2Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST2 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST2 - skimming example using ExpressionEvaluation """
     statusOn     = True
     allowedTypes = ['bool']
@@ -42,7 +55,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST2Stream
 
 class WriteDAOD_TEST3Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST3 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST3 - skimming example using augmentations """
     statusOn     = True
     allowedTypes = ['bool']
@@ -55,7 +68,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST3Stream
 
 class WriteDAOD_TEST4Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST4 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST4 - slimming example """
     statusOn     = True
     allowedTypes = ['bool']
@@ -68,7 +81,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST4Stream
 
 class WriteDAOD_TEST5Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST5 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST5 - CP tools example """
     statusOn     = True
     allowedTypes = ['bool']
@@ -81,7 +94,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST5Stream
 
 class WriteDAOD_TEST6Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST6 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST6 - private sequencer example """
     statusOn     = True
     allowedTypes = ['bool']
@@ -94,7 +107,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST6Stream
 
 class WriteDAOD_TEST7Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST7 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST7 - augmentation example """
     statusOn     = True
     allowedTypes = ['bool']
@@ -107,7 +120,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST7Stream
 
 class WriteDAOD_TEST8Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST8 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST8 - thinning example """
     statusOn     = True
     allowedTypes = ['bool']
@@ -120,7 +133,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST8Stream
 
 class WriteDAOD_TEST9Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST9 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST9 - example of adding reconstruction tools """
     statusOn     = True
     allowedTypes = ['bool']
@@ -133,7 +146,7 @@ jobproperties.DerivationFrameworkProdFlags.add_JobProperty(WriteDAOD_TEST9Stream
 
 class WriteDAOD_TEST10Stream(JobProperty):
-    """ Produce the DPD for DAOD_TEST10 - derivation framework test """
+    """ Produce the DPD for DAOD_TEST10 - example of trigger content management """
     statusOn     = True
     allowedTypes = ['bool']